@@ -9,6 +9,7 @@ from typing import (
     List,
     Optional,
     Sequence,
+    Set,
     Tuple,
     TypedDict,
     Union,
@@ -211,17 +212,11 @@ class TransformerRETextClassificationTaskModule(_TransformerReTextClassification
         return self.entity_labels is not None and self.label_to_id is not None
 
     def prepare(self, documents: List[Document]) -> None:
-        entity_labels = set()
-        relation_labels = set()
+        entity_labels: Set[str] = set()
+        relation_labels: Set[str] = set()
         for document in documents:
-            entities = document.span_annotations(self.entity_annotation)
-            relations = document.relation_annotations(self.relation_annotation)
-            assert (
-                entities is not None
-            ), f"document has no span annotations with name '{self.entity_annotation}'"
-            assert (
-                relations is not None
-            ), f"document has no relation annotations with name '{self.relation_annotation}'"
+            entities = document.annotations.spans[self.entity_annotation]
+            relations = document.annotations.binary_relations[self.relation_annotation]
 
             if self.add_type_to_marker:
                 for entity in entities:
@@ -271,7 +266,9 @@ class TransformerRETextClassificationTaskModule(_TransformerReTextClassification
         return encoding
 
     def encode_input(
-        self, documents: List[Document]
+        self,
+        documents: List[Document],
+        is_training: bool = False,
     ) -> Tuple[
         List[TransformerReTextClassificationInputEncoding],
         List[Metadata],
@@ -291,20 +288,16 @@ class TransformerRETextClassificationTaskModule(_TransformerReTextClassification
         )
 
         for document in documents:
-            entities = document.span_annotations(self.entity_annotation)
-            assert (
-                entities is not None
-            ), f"document has no span annotations of name {self.entity_annotation}"
-            relations = document.relation_annotations(self.relation_annotation)
+            entities = document.annotations.spans[self.entity_annotation]
+            if document.annotations.binary_relations.has_layer(self.relation_annotation):
+                relations = document.annotations.binary_relations[self.relation_annotation]
+            else:
+                relations = None
             relation_mapping = {(rel.head, rel.tail): rel.label for rel in relations or []}
 
             partitions: Sequence[Optional[LabeledSpan]]
             if self.partition_annotation is not None:
-                partitions_or_none = document.span_annotations(self.partition_annotation)
-                assert (
-                    partitions_or_none is not None
-                ), f"document has no span annotations of name {self.partition_annotation}"
-                partitions = partitions_or_none
+                partitions = document.annotations.spans[self.partition_annotation]
             else:
                 # use single dummy partition
                 partitions = [None]
@@ -446,11 +439,7 @@ class TransformerRETextClassificationTaskModule(_TransformerReTextClassification
         target: List[TransformerReTextClassificationTargetEncoding] = []
         for i, document in enumerate(documents):
             meta = metadata[i]
-
-            relations = document.relation_annotations(self.relation_annotation)
-            assert (
-                relations is not None
-            ), f"document has no relation annotations of name '{self.relation_annotation}'"
+            relations = document.annotations.binary_relations[self.relation_annotation]
 
             head_tail_to_labels = {
                 (relation.head, relation.tail): relation.labels for relation in relations
